<?php
/**
* Livechatoo
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
* @author Livechatoo <support@livechatoo.com>
* @copyright © Livechatoo
* @license http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*
* Compatible with PrestaShop version 1.3.x and newer
*/

if (!defined('_PS_VERSION_')) {
    exit;
}

class Livechatoo extends Module
{
    public function __construct()
    {
        $this->name = 'livechatoo';
        $this->tab = 'advertising_marketing';
        $this->version = '1.1.0';
        $this->author = 'Livechatoo';
        $this->bootstrap = true;

        // avoid comparison bug in some 1.5.x versions by adding '.1' at the end of max
        $this->ps_versions_compliancy = array('min' => '1.3', 'max' => _PS_VERSION_ . '.1');

        $this->module_key = 'fa103220ce1d4f021d0853f5025530bb';

        parent::__construct();

        $this->displayName = $this->l('Livechatoo');
        $this->description = $this->l('PrestaShop module to insert Livechatoo JavaScript code to your website');
    }

    public function install()
    {
        if (!parent::install()) {
            return false;
        }

        if (!$this->registerHook('header')) {
            return false;
        }

        if (!Configuration::updateValue('LIVECHATOO_JSCODE', null)) {
            return false;
        }

        return true;
    }

    public function uninstall()
    {
        if (!parent::uninstall()) {
            return false;
        }

        Configuration::deleteByName('LIVECHATOO_JSCODE');

        return true;
    }

    public function getContent()
    {
        $content = '';
        if (Tools::isSubmit('submitlivechatoo')) {
            $success = Configuration::updateValue('LIVECHATOO_JSCODE', Tools::getValue('livechatoo_jscode'), true);
            if ($success && method_exists($this, 'displayConfirmation')) {
                $content = $this->displayConfirmation($this->l('The changes have been saved'));
            } elseif (method_exists($this, 'displayError')) {
                $content = $this->displayError($this->l('Failed to save changes'));
            }
        }

        if (version_compare(_PS_VERSION_, '1.5', '<')) {
            return $content . $this->displayFormObsolete();
        } else {
            return $content . $this->displayForm();
        }
    }

    public function displayForm()
    {
        $fields = array(0 => array());
        $fields[0]['form'] = array(
            'legend' => array(
                'title' => $this->l('Settings'),
            ),
            'input' => array(
                array(
                    'type' => 'textarea',
                    'label' => $this->l('JavaScript Code'),
                    'name' => 'livechatoo_jscode',
                    'desc' => $this->l('You can replace permanent language code to {auto} variable for automatic use of your site language in Livechatoo (for example change lang: \'en\' to lang: \'{auto}\').'),
                    'rows' => 12,
                    'hint' => $this->l('Enter your Livechatoo JavaScript code'),
                )
            ),
            'submit' => array(
                'title' => $this->l('Save Changes'),
            )
        );
    
        $helper = new HelperForm();
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex = AdminController::$currentIndex . '&configure=' . $this->name;
        $helper->submit_action = 'submitlivechatoo';
        $helper->fields_value['livechatoo_jscode'] = Configuration::get('LIVECHATOO_JSCODE');
        $form = $helper->generateForm($fields);
        $form = str_replace('name="livechatoo_jscode"', 'name="livechatoo_jscode" placeholder="&lt;!-- ' . htmlspecialchars($this->l('Paste here your Livechatoo JavaScript code'))  . ' --&gt;"', $form);
        return $form;
    }

    public function displayFormObsolete()
    {
        $vars = array(
            'legend' => $this->l('Livechatoo'),
            'hideHint' => (version_compare(_PS_VERSION_, '1.5', '<')) ? ' display: none;' : '',
            'hintMessage' => $this->l('You can replace permanent language code to {auto} variable for automatic use of your site language in Livechatoo (for example change lang: \'en\' to lang: \'{auto}\').'),
            'textareaPlaceholder' => $this->l('Paste here your Livechatoo JavaScript code'),
            'textareaContent' => Configuration::get('LIVECHATOO_JSCODE'),
            'saveChanges' => $this->l('Save Changes'),
        );

        if (version_compare(_PS_VERSION_, '1.4', '<')) {
            $template = call_user_func('file_get_contents', dirname(__FILE__) . '/views/templates/admin/form.tpl');
        } else {
            $template = Tools::file_get_contents(dirname(__FILE__) . '/views/templates/admin/form.tpl');
        }
        $template = explode('*}', $template);
        $template = $template[1];

        foreach ($vars as $key => $value) {
            $template = str_replace(
                '{$' . $key . '|escape:\'htmlall\':\'UTF-8\'}',
                htmlspecialchars($value),
                $template
            );
        }

        return $template;
    }

    public function hookHeader()
    {
        $jscode = Configuration::get('LIVECHATOO_JSCODE');

        if (!empty($jscode)) {
            // set Livechatoo language in JS code automatically by website language
            // note that $this->context is not available on PrestaShop 1.4.x and older
            if ($this->context && $this->context->language && $this->context->language->iso_code) {
                $lang = $this->context->language->iso_code;
            } else {
                $lang = '';
            }
            $jscode = str_replace('{auto}', $lang, $jscode);

            // append Livechatoo JS code to document
            return "\n" . $jscode . "\n";
        }
    }
}
